from typing import Optional, Union, Tuple
import customtkinter as ctk
from customtkinter import CTkFont, ThemeManager

from ..utils.params import Strings


class CTkLoginBox(ctk.CTkToplevel):

    def __init__(self,
                 title: str = "LoginBox",
                 greeting: str = "LoginBox",
                 font: Optional[Union[tuple, CTkFont]] = None,

                 fg_color: Optional[Union[str, Tuple[str, str]]] = None,
                 text_color: Optional[Union[str, Tuple[str, str]]] = None,
                 button_fg_color: Optional[Union[str, Tuple[str, str]]] = None,
                 button_hover_color: Optional[Union[str, Tuple[str, str]]] = None,
                 button_text_color: Optional[Union[str, Tuple[str, str]]] = None,
                 entry_fg_color: Optional[Union[str, Tuple[str, str]]] = None,
                 entry_border_color: Optional[Union[str, Tuple[str, str]]] = None,
                 entry_text_color: Optional[Union[str, Tuple[str, str]]] = None,

                 stings=Strings,

                 parent=None,
                 header=None):

        super().__init__(fg_color=fg_color)

        self._fg_color = ThemeManager.theme["CTkToplevel"]["fg_color"] if fg_color is None else self._check_color_type(fg_color)
        self._text_color = ThemeManager.theme["CTkLabel"]["text_color"] if text_color is None else self._check_color_type(text_color)
        self._button_fg_color = ThemeManager.theme["CTkButton"]["fg_color"] if button_fg_color is None else self._check_color_type(button_fg_color)
        self._button_hover_color = ThemeManager.theme["CTkButton"]["hover_color"] if button_hover_color is None else self._check_color_type(button_hover_color)
        self._button_text_color = ThemeManager.theme["CTkButton"]["text_color"] if button_text_color is None else self._check_color_type(button_text_color)
        self._entry_fg_color = ThemeManager.theme["CTkEntry"]["fg_color"] if entry_fg_color is None else self._check_color_type(entry_fg_color)
        self._entry_border_color = ThemeManager.theme["CTkEntry"]["border_color"] if entry_border_color is None else self._check_color_type(entry_border_color)
        self._entry_text_color = ThemeManager.theme["CTkEntry"]["text_color"] if entry_text_color is None else self._check_color_type(entry_text_color)

        self.__strings = stings
        self._header = header
        self._greeting = greeting
        self._font = font
        self._input = None

        self._parent = parent

        self.transient(parent)
        self.title(title)
        self.lift()
        self.protocol("WM_DELETE_WINDOW", self._on_closing)
        self._create_widgets()
        self.resizable(False, False)
        self.grab_set()

    def get_parent(self):
        return self._parent

    def set_greeting(self, greeting):
        self._greeting = greeting

    def _on_closing(self):
        self.grab_release()
        self.destroy()

    def _center(self):
        self.update_idletasks()
        x = (self.winfo_screenwidth() - self.winfo_reqwidth())
        y = (self.winfo_screenheight() - self.winfo_reqheight())
        self.geometry('+{}+{}'.format(x, y))

    def _create_widgets(self):
        if self._header:
            self._header(self, self.title(), disable_hide=True, disable_close=True, transient=True)

        # Основная рамка
        main_frame = ctk.CTkFrame(self)
        main_frame.focus_set()
        main_frame.pack(pady=(5, 10), padx=10, fill="x")

        # Настраиваем веса столбцов: 1/3 для метки, 2/3 для ввода
        main_frame.grid_columnconfigure(0, weight=1)  # Первый столбец (метки)
        main_frame.grid_columnconfigure(1, weight=2)  # Второй столбец (поля ввода)

        # Приветствие
        label_greeting = ctk.CTkLabel(main_frame, text=self._greeting, anchor="center")
        label_greeting.grid(row=0, column=0, pady=5, sticky="nsew", columnspan=2)

        # Логин
        label_login = ctk.CTkLabel(main_frame, text=self.__strings.login)
        label_login.grid(row=1, column=0, padx=10, pady=5, sticky="w")  # Выравнивание влево

        self.entry_login = ctk.CTkEntry(main_frame)
        self.entry_login.grid(row=1, column=0, padx=(80, 5), pady=5, sticky="we", columnspan=2)  # Выравнивание + растяжение

        # Пароль
        label_password = ctk.CTkLabel(main_frame, text=self.__strings.password)
        label_password.grid(row=2, column=0, padx=10, pady=5, sticky="w")  # Выравнивание влево

        self.entry_password = ctk.CTkEntry(main_frame, show="・")
        self.entry_password.grid(row=2, column=0, padx=(80, 5), pady=5, sticky="we", columnspan=2)  # Выравнивание + растяжение

        # Кнопки
        btn_ok = ctk.CTkButton(main_frame, text=self.__strings.ok, command=self._on_ok)
        btn_ok.grid(row=3, column=0, padx=10, pady=10, sticky="e")  # Выравнивание вправо

        btn_cancel = ctk.CTkButton(main_frame, text=self.__strings.cancel, command=self._on_cancel)
        btn_cancel.grid(row=3, column=1, padx=10, pady=10, sticky="e")  # Выравнивание вправо

    def _on_ok(self):
        self._input = [
            self.entry_login.get(),
            self.entry_password.get()
        ]
        self._on_closing()

    def _on_cancel(self):
        self._input = None
        self._on_closing()

    def get_output(self):
        self._center()
        self.master.wait_window(self)
        return self._input


if __name__ == '__main__':
    root = ctk.CTk()
    root.withdraw()
    login_box = CTkLoginBox(parent=root)
    result = login_box.get_output()
    print(result)
    # root.mainloop()
